from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="Ref")


@attr.s(auto_attribs=True)
class Ref:
    """ """

    type: Union[Unset, str] = UNSET
    target: Union[Unset, str] = UNSET
    start: Union[Unset, int] = UNSET
    end: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        type = self.type
        target = self.target
        start = self.start
        end = self.end

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if type is not UNSET:
            field_dict["type"] = type
        if target is not UNSET:
            field_dict["target"] = target
        if start is not UNSET:
            field_dict["start"] = start
        if end is not UNSET:
            field_dict["end"] = end

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = d.pop("type", UNSET)

        target = d.pop("target", UNSET)

        start = d.pop("start", UNSET)

        end = d.pop("end", UNSET)

        ref = cls(
            type=type,
            target=target,
            start=start,
            end=end,
        )

        return ref



""" Contains some shared types for properties """
import re
from typing import BinaryIO, Generic, List, MutableMapping, Optional, TextIO, Tuple, TypeVar, Union

import attr
from httpx import HTTPError, codes


class Unset:
    def __bool__(self) -> bool:
        return False


UNSET: Unset = Unset()
FileJsonType = Tuple[Optional[str], Union[BinaryIO, TextIO], Optional[str]]


@attr.s(auto_attribs=True)
class File:
    """Contains information for file uploads"""

    payload: Union[BinaryIO, TextIO]
    file_name: Optional[str] = None
    mime_type: Optional[str] = None

    def to_tuple(self) -> FileJsonType:
        """Return a tuple representation that httpx will accept for multipart/form-data"""
        return self.file_name, self.payload, self.mime_type


T = TypeVar("T")


@attr.s(auto_attribs=True)
class Response(Generic[T]):
    """A response from an endpoint"""

    status_code: int
    content: bytes
    headers: MutableMapping[str, str]
    parsed: Optional[T]

    @property
    def is_informational(self) -> bool:
        """
        A property which is `True` for 1xx status codes, `False` otherwise.
        """
        return codes.is_informational(self.status_code)

    @property
    def is_success(self) -> bool:
        """
        A property which is `True` for 2xx status codes, `False` otherwise.
        """
        return codes.is_success(self.status_code)

    @property
    def is_redirect(self) -> bool:
        """
        A property which is `True` for 3xx status codes, `False` otherwise.

        Note that not all responses with a 3xx status code indicate a URL redirect.

        Use `response.has_redirect_location` to determine responses with a properly
        formed URL redirection.
        """
        return codes.is_redirect(self.status_code)

    @property
    def is_client_error(self) -> bool:
        """
        A property which is `True` for 4xx status codes, `False` otherwise.
        """
        return codes.is_client_error(self.status_code)

    @property
    def is_server_error(self) -> bool:
        """
        A property which is `True` for 5xx status codes, `False` otherwise.
        """
        return codes.is_server_error(self.status_code)

    @property
    def is_error(self) -> bool:
        """
        A property which is `True` for 4xx and 5xx status codes, `False` otherwise.
        """
        return codes.is_error(self.status_code)

    @property
    def has_redirect_location(self) -> bool:
        """
        Returns True for 3xx responses with a properly formed URL redirection,
        `False` otherwise.
        """
        return (
            self.status_code
            in (
                # 301 (Cacheable redirect. Method may change to GET.)
                codes.MOVED_PERMANENTLY,
                # 302 (Uncacheable redirect. Method may change to GET.)
                codes.FOUND,
                # 303 (Client should make a GET or HEAD request.)
                codes.SEE_OTHER,
                # 307 (Equiv. 302, but retain method)
                codes.TEMPORARY_REDIRECT,
                # 308 (Equiv. 301, but retain method)
                codes.PERMANENT_REDIRECT,
            )
            and "Location" in self.headers
        )

    def raise_for_status(self):
        """Raises :class:`HTTPError`, if one occurred."""

        http_error_msg = ""
        if isinstance(self.content, bytes):
            # We attempt to decode utf-8 first because some servers
            # choose to localize their reason strings. If the string
            # isn't utf-8, we fall back to iso-8859-1 for all other
            # encodings. (See PR #3538)
            try:
                reason = self.content.decode("utf-8")
            except UnicodeDecodeError:
                reason = self.content.decode("iso-8859-1")
        else:
            reason = self.content

        if 400 <= self.status_code < 500:
            http_error_msg = "%s Client Error: %s" % (self.status_code, reason)

        elif 500 <= self.status_code < 600:
            http_error_msg = "%s Server Error: %s" % (self.status_code, reason)

        if http_error_msg:
            raise HTTPError(http_error_msg)


from bs4 import BeautifulSoup, CData, NavigableString, Tag
from dateutil import parser


class TEI:
    """
    Methods to transform TEI (Text Encoding Initiative) XML into article objects.
    """

    @staticmethod
    def parse(stream, figures=False):
        """
        Parses a TEI XML datastream and returns a processed article.

        Args:
            stream: handle to input data stream
        Returns:
            Article
        """
        from .models import Article, ArticleCitations

        soup = BeautifulSoup(stream, "lxml")
        sentences = soup.find("s") is not None
        title = soup.title.text
        art = Article(identifier=None, title=title)
        source = soup.find("sourcedesc")
        if source:
            struct = source.find("biblstruct")
            art.bibliography = TEI.citation(struct)
            if art.bibliography.ids:
                art.identifier = art.bibliography.ids["MD5"]

        # Parse text sections
        art.sections = TEI.text(soup, title, sentences, figures)

        listBibl = soup.find("listbibl")
        if listBibl:
            art.citations = ArticleCitations()
            for struct in listBibl.find_all("biblstruct"):
                name = struct.get("xml:id")
                art.citations.additional_properties[name] = TEI.citation(struct)
        return art

    @staticmethod
    def date(published):
        """
        Attempts to parse a publication date, if available. Otherwise, None is returned.

        Args:
            published: published object

        Returns:
            publication date if available/found, None otherwise
        """

        # Parse publication date
        # pylint: disable=W0702
        try:
            published = parser.parse(published["when"]) if published and "when" in published.attrs else None
        except:
            published = None

        return published

    @staticmethod
    def authors(source):
        """
        Parses authors and associated affiliations from the article.

        Args:
            elements: authors elements

        Returns:
            (semicolon separated list of authors, semicolon separated list of affiliations, primary affiliation)
        """
        from .models import Address, Affiliation, Author, PersName

        authors: List[Author] = []
        for author in source.find_all("author"):
            auth: Author = None
            affiliations: List[Affiliation] = []
            name = author.find("persname")
            if name:
                surname = name.find("surname")
                if surname:
                    pers = PersName(surname=surname.text)
                    auth = Author(pers_name=pers)
                    authors.append(auth)
                    for forename in name.find_all("forename"):
                        if "type" in forename.attrs and forename["type"] == "first":
                            pers.firstname = forename.text
                        elif "type" in forename.attrs and forename["type"] == "middle":
                            pers.middlename = forename.text
            if auth:
                email = author.find("email")
                if email:
                    auth.email = email.text
                for affiliation in author.find_all("affiliation"):
                    aff = Affiliation()
                    affiliations.append(aff)
                    for orgName in affiliation.find_all("orgname"):
                        if "type" in orgName.attrs and orgName["type"] == "institution":
                            aff.institution = orgName.text
                        if "type" in orgName.attrs and orgName["type"] == "department":
                            aff.department = orgName.text
                        if "type" in orgName.attrs and orgName["type"] == "laboratory":
                            aff.laboratory = orgName.text
                    auth.affiliations = affiliations
                    address = author.find("address")
                    if address:
                        aff.address = Address.from_dict(
                            {el.name: el.text for el in address.children if isinstance(el, Tag)}
                        )

        return authors

    @staticmethod
    def citation(struct):
        """
        Extracts article citation.
        """
        from .models import Citation, CitationIds, CitationScopes, CitationTitles

        citation = Citation()
        citation.authors = TEI.authors(struct)
        published = struct.find("date", attrs={"type": "published"})
        if published:
            # Parse publication information
            citation.published = TEI.date(published)
        publisher = struct.find("publisher")
        if publisher:
            citation.publisher = publisher.text
        ids_dict = {}
        for idno in struct.find_all("idno"):
            if "type" in idno.attrs:
                ids_dict[idno["type"]] = idno.text
        if ids_dict:
            citation.ids = CitationIds.from_dict(ids_dict)
        titles_dict = {}
        for title in struct.find_all("title"):
            if "level" in title.attrs:
                titles_dict[title["level"]] = title.text
        if len(titles_dict) > 0:
            citation.titles = CitationTitles.from_dict(titles_dict)
        citation.main_title = citation.titles.additional_properties.get("a", None)
        scopes_dict = {}
        for scope in struct.find_all("biblscope"):
            if "unit" in scope.attrs:
                val = []
                if "from" in scope.attrs:
                    val.append(scope["from"])
                if "to" in scope.attrs:
                    val.append(scope["to"])
                if not val:
                    val = scope.text
                scopes_dict[scope["unit"]] = str(val)
        if len(scopes_dict) > 0:
            citation.scopes = CitationScopes.from_dict(scopes_dict)
        return citation

    @staticmethod
    def abstract(soup, title, sentences=False):
        """
        Builds a list of title and abstract sections.

        Args:
            soup: bs4 handle
            title: article title

        Returns:
            list of sections
        """
        from .models import Section, TextWithRefs

        title_refs = TextWithRefs(text=title)
        sections = [Section("TITLE", paragraphs=[[title_refs]] if sentences else [title_refs])]

        abstract = soup.find("abstract")
        secs = []
        if abstract:
            for div in abstract.find_all("div", recursive=False):
                sec = TEI.section("ABSTRACT", div.children, sentences)
                secs.append(sec)
            sections.extend(secs)

        return sections

    @staticmethod
    def section(name, children, sentences=False):
        from .models import Section, TextWithRefs

        sec = Section(name=name, paragraphs=[])
        for p in children:
            if p:
                if sentences:
                    if isinstance(p, Tag) and p.name == "p":
                        sents = []
                        for s in p.children:
                            if isinstance(s, Tag) and s.name == "s":
                                sents.append(TEI.text_with_refs(s))
                            else:
                                sents.append(TextWithRefs(text=str(s)))
                        sec.paragraphs.append(sents)
                    else:
                        sec.paragraphs.append([TextWithRefs(text=str(p))])
                else:
                    if isinstance(p, Tag) and p.name == "p":
                        sec.paragraphs.append(TEI.text_with_refs(p))
                    else:
                        sec.paragraphs.append(TextWithRefs(text=str(p)))
        return sec

    @staticmethod
    def text(soup, title, sentences=False, figures=False):
        """
        Builds a list of text sections.

        Args:
            soup: bs4 handle
            title: article title

        Returns:
            list of sections
        """

        # Initialize with title and abstract text
        sections = TEI.abstract(soup, title, sentences)

        secs = []
        div_or_fig = re.compile("div|figure") if figures else "div"
        for section in soup.find("text").find_all(div_or_fig, recursive=False):
            # Section name and text
            children = list(section.children)
            # Attempt to parse section header
            if children and not children[0].name:
                name = str(children[0])
                children = children[1:]
            else:
                name = None
            if section.name == "div":
                sec = TEI.section(name, children, sentences)
                secs.append(sec)
            elif section.name == "figure":
                label = None
                if children and children[0].name == "label":
                    label = children[0].text
                    children = children[1:]
                desc = None
                if children and children[0].name == "figdesc":
                    desc = children[0].find("div") or children[0]
                children = [name, label]
                if desc:
                    children.extend(desc.children)
                # Use XML Id as figure name to ensure figures are uniquely named
                name = section.get("xml:id")
                sec = TEI.section(name, children, sentences)
                secs.append(sec)
            # Transform and clean text
            # text = Text.transform(text)
            # Split text into sentences, transform text and add to sections
        sections.extend(secs)

        # Extract text from tables
        # for figure in soup.find("text").find_all("figure"):
        #     name = figure.get("xml:id").upper()
        #
        #     figure.find("table")
        #     # if table:
        #     #     sections.extend([(name, x) for x in Table.extract(table)])

        return sections

    @staticmethod
    def text_with_refs(node):
        from .models import Ref, TextWithRefs

        str_and_refs = TEI._all_strings_and_refs(node)
        text = ""
        start = 0
        refs = []
        for el in str_and_refs:
            start = len(text)
            if isinstance(el, Tag):
                end = start + len(el.text)
                ref = Ref(start=start, end=end)
                if "type" in el.attrs:
                    ref.type = el["type"]
                if "target" in el.attrs:
                    ref.target = el["target"]
                refs.append(ref)
            else:
                text += str(el)
        return TextWithRefs(text=text, refs=refs)

    @staticmethod
    def _all_strings_and_refs(node, reftag="ref", strip=False):
        types = (NavigableString, CData)
        for descendant in node.descendants:
            if types is None and not isinstance(descendant, NavigableString):
                continue
            descendant_type = type(descendant)
            if isinstance(types, type):
                if descendant_type is not types:
                    # We're not interested in strings of this type.
                    continue
            elif descendant_type is Tag and descendant.name == reftag:
                yield descendant
            elif types is not None and descendant_type not in types:
                # We're not interested in strings of this type.
                continue
            else:
                if strip:
                    descendant = descendant.strip()
                    if len(descendant) == 0:
                        continue
                yield descendant


__all__ = ["File", "Response", "FileJsonType", "TEI"]



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.address import Address
from ..types import UNSET, Unset

T = TypeVar("T", bound="Affiliation")


@attr.s(auto_attribs=True)
class Affiliation:
    """ """

    institution: Union[Unset, str] = UNSET
    department: Union[Unset, str] = UNSET
    laboratory: Union[Unset, str] = UNSET
    acronym: Union[Unset, str] = UNSET
    url: Union[Unset, str] = UNSET
    address: Union[Unset, List[Address]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        institution = self.institution
        department = self.department
        laboratory = self.laboratory
        acronym = self.acronym
        url = self.url
        address: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.address, Unset):
            address = []
            for address_item_data in self.address:
                address_item = address_item_data.to_dict()

                address.append(address_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if institution is not UNSET:
            field_dict["institution"] = institution
        if department is not UNSET:
            field_dict["department"] = department
        if laboratory is not UNSET:
            field_dict["laboratory"] = laboratory
        if acronym is not UNSET:
            field_dict["acronym"] = acronym
        if url is not UNSET:
            field_dict["url"] = url
        if address is not UNSET:
            field_dict["address"] = address

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        institution = d.pop("institution", UNSET)

        department = d.pop("department", UNSET)

        laboratory = d.pop("laboratory", UNSET)

        acronym = d.pop("acronym", UNSET)

        url = d.pop("url", UNSET)

        address = []
        _address = d.pop("address", UNSET)
        for address_item_data in _address or []:
            address_item = Address.from_dict(address_item_data)

            address.append(address_item)

        affiliation = cls(
            institution=institution,
            department=department,
            laboratory=laboratory,
            acronym=acronym,
            url=url,
            address=address,
        )

        return affiliation



from io import BytesIO
from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, File, Unset

T = TypeVar("T", bound="ProcessForm")


@attr.s(auto_attribs=True)
class ProcessForm:
    """ """

    input_: File
    generate_ids: Union[Unset, str] = UNSET
    consolidate_header: Union[Unset, str] = UNSET
    consolidate_citations: Union[Unset, str] = UNSET
    include_raw_citations: Union[Unset, str] = UNSET
    include_raw_affiliations: Union[Unset, str] = UNSET
    tei_coordinates: Union[Unset, str] = UNSET
    segment_sentences: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        input_ = self.input_.to_tuple()

        generate_ids = self.generate_ids
        consolidate_header = self.consolidate_header
        consolidate_citations = self.consolidate_citations
        include_raw_citations = self.include_raw_citations
        include_raw_affiliations = self.include_raw_affiliations
        tei_coordinates = self.tei_coordinates
        segment_sentences = self.segment_sentences

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "input": input_,
            }
        )
        if generate_ids is not UNSET:
            field_dict["generateIDs"] = generate_ids
        if consolidate_header is not UNSET:
            field_dict["consolidateHeader"] = consolidate_header
        if consolidate_citations is not UNSET:
            field_dict["consolidateCitations"] = consolidate_citations
        if include_raw_citations is not UNSET:
            field_dict["includeRawCitations"] = include_raw_citations
        if include_raw_affiliations is not UNSET:
            field_dict["includeRawAffiliations"] = include_raw_affiliations
        if tei_coordinates is not UNSET:
            field_dict["teiCoordinates"] = tei_coordinates
        if segment_sentences is not UNSET:
            field_dict["segmentSentences"] = segment_sentences

        return field_dict

    def to_multipart(self) -> Dict[str, Any]:
        input_ = self.input_.to_tuple()

        generate_ids = (
            self.generate_ids if self.generate_ids is UNSET else (None, str(self.generate_ids).encode(), "text/plain")
        )
        consolidate_header = (
            self.consolidate_header
            if self.consolidate_header is UNSET
            else (None, str(self.consolidate_header).encode(), "text/plain")
        )
        consolidate_citations = (
            self.consolidate_citations
            if self.consolidate_citations is UNSET
            else (None, str(self.consolidate_citations).encode(), "text/plain")
        )
        include_raw_citations = (
            self.include_raw_citations
            if self.include_raw_citations is UNSET
            else (None, str(self.include_raw_citations).encode(), "text/plain")
        )
        include_raw_affiliations = (
            self.include_raw_affiliations
            if self.include_raw_affiliations is UNSET
            else (None, str(self.include_raw_affiliations).encode(), "text/plain")
        )
        tei_coordinates = (
            self.tei_coordinates
            if self.tei_coordinates is UNSET
            else (None, str(self.tei_coordinates).encode(), "text/plain")
        )
        segment_sentences = (
            self.segment_sentences
            if self.segment_sentences is UNSET
            else (None, str(self.segment_sentences).encode(), "text/plain")
        )

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "input": input_,
            }
        )
        if generate_ids is not UNSET:
            field_dict["generateIDs"] = generate_ids
        if consolidate_header is not UNSET:
            field_dict["consolidateHeader"] = consolidate_header
        if consolidate_citations is not UNSET:
            field_dict["consolidateCitations"] = consolidate_citations
        if include_raw_citations is not UNSET:
            field_dict["includeRawCitations"] = include_raw_citations
        if include_raw_affiliations is not UNSET:
            field_dict["includeRawAffiliations"] = include_raw_affiliations
        if tei_coordinates is not UNSET:
            field_dict["teiCoordinates"] = tei_coordinates
        if segment_sentences is not UNSET:
            field_dict["segmentSentences"] = segment_sentences

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        input_ = File(payload=BytesIO(d.pop("input")))

        generate_ids = d.pop("generateIDs", UNSET)

        consolidate_header = d.pop("consolidateHeader", UNSET)

        consolidate_citations = d.pop("consolidateCitations", UNSET)

        include_raw_citations = d.pop("includeRawCitations", UNSET)

        include_raw_affiliations = d.pop("includeRawAffiliations", UNSET)

        tei_coordinates = d.pop("teiCoordinates", UNSET)

        segment_sentences = d.pop("segmentSentences", UNSET)

        process_form = cls(
            input_=input_,
            generate_ids=generate_ids,
            consolidate_header=consolidate_header,
            consolidate_citations=consolidate_citations,
            include_raw_citations=include_raw_citations,
            include_raw_affiliations=include_raw_affiliations,
            tei_coordinates=tei_coordinates,
            segment_sentences=segment_sentences,
        )

        return process_form



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.article_citations import ArticleCitations
from ..models.citation import Citation
from ..models.section import Section
from ..types import UNSET, Unset

T = TypeVar("T", bound="Article")


@attr.s(auto_attribs=True)
class Article:
    """ """

    identifier: str
    title: str
    bibliography: Union[Unset, Citation] = UNSET
    sections: Union[Unset, List[Section]] = UNSET
    citations: Union[Unset, ArticleCitations] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        identifier = self.identifier
        title = self.title
        bibliography: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.bibliography, Unset):
            bibliography = self.bibliography.to_dict()

        sections: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sections, Unset):
            sections = []
            for sections_item_data in self.sections:
                sections_item = sections_item_data.to_dict()

                sections.append(sections_item)

        citations: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.citations, Unset):
            citations = self.citations.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "identifier": identifier,
                "title": title,
            }
        )
        if bibliography is not UNSET:
            field_dict["bibliography"] = bibliography
        if sections is not UNSET:
            field_dict["sections"] = sections
        if citations is not UNSET:
            field_dict["citations"] = citations

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        identifier = d.pop("identifier")

        title = d.pop("title")

        _bibliography = d.pop("bibliography", UNSET)
        bibliography: Union[Unset, Citation]
        if isinstance(_bibliography, Unset):
            bibliography = UNSET
        else:
            bibliography = Citation.from_dict(_bibliography)

        sections = []
        _sections = d.pop("sections", UNSET)
        for sections_item_data in _sections or []:
            sections_item = Section.from_dict(sections_item_data)

            sections.append(sections_item)

        _citations = d.pop("citations", UNSET)
        citations: Union[Unset, ArticleCitations]
        if isinstance(_citations, Unset):
            citations = UNSET
        else:
            citations = ArticleCitations.from_dict(_citations)

        article = cls(
            identifier=identifier,
            title=title,
            bibliography=bibliography,
            sections=sections,
            citations=citations,
        )

        return article



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['grobid_client',
 'grobid_client.api',
 'grobid_client.api.pdf',
 'grobid_client.models']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=20.1.0,<22.0.0',
 'beautifulsoup4>=4.10.0,<5.0.0',
 'h11>=0.12.0',
 'httpx>=0.15.4,<0.23.0',
 'lxml>=4.7.1,<5.0.0',
 'python-dateutil>=2.8.0,<3.0.0']

setup_kwargs = {
    'name': 'grobid-client',
    'version': '0.8.1',
    'description': 'A client library for accessing Grobid',
    'long_description': '# grobid-client\nA client library for accessing [Grobid](https://github.com/kermitt2/grobid)\n\n## Usage\nFirst, create a client:\n\n```python\nfrom grobid_client import Client\n\nclient = Client(base_url="https://cloud.science-miner.com/grobid/api")\n```\n\nNow call your endpoint and use your models:\n\n```python\nfrom pathlib import Path\nfrom grobid_client.api.pdf import process_fulltext_document\nfrom grobid_client.models import Article, ProcessForm\nfrom grobid_client.types import TEI, File\npdf_file = "MyPDFFile.pdf"\nwith pdf_file.open("rb") as fin:\n    form = ProcessForm(\n        segment_sentences="1",\n        input_=File(file_name=pdf_file.name, payload=fin, mime_type="application/pdf),\n    )\n    r = process_fulltext_document.sync_detailed(client=client, multipart_data=form)\n    if r.is_success:\n        article: Article = TEI.parse(r.content, figures=False)\n        assert article.title\n\n```\n\nThings to know:\n1. Every path/method combo becomes a Python module with four functions:\n    1. `sync`: Blocking request that returns parsed data (if successful) or `None`\n    1. `sync_detailed`: Blocking request that always returns a `Request`, optionally with `parsed` set if the request was successful.\n    1. `asyncio`: Like `sync` but the async instead of blocking\n    1. `asyncio_detailed`: Like `sync_detailed` by async instead of blocking\n\n1. All path/query params, and bodies become method arguments.\n1. If your endpoint had any tags on it, the first tag will be used as a module name for the function (my_tag above)\n1. Any endpoint which did not have a tag will be in `entifyfishing_client.api.default`\n\n## Building / publishing this Client\nThis project uses [Poetry](https://python-poetry.org/) to manage dependencies  and packaging.  Here are the basics:\n1. Update the metadata in pyproject.toml (e.g. authors, version)\n1. If you\'re using a private repository, configure it with Poetry\n    1. `poetry config repositories.<your-repository-name> <url-to-your-repository>`\n    1. `poetry config http-basic.<your-repository-name> <username> <password>`\n1. Publish the client with `poetry publish --build -r <your-repository-name>` or, if for public PyPI, just `poetry publish --build`\n\nIf you want to install this client into another project without publishing it (e.g. for development) then:\n1. If that project **is using Poetry**, you can simply do `poetry add <path-to-this-client>` from that project\n1. If that project is not using Poetry:\n    1. Build a wheel with `poetry build -f wheel`\n    1. Install that wheel from the other project `pip install <path-to-wheel>`\n',
    'author': None,
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
